Agent skill · AI & Agents

gpu-memory-analysis

Specialized skill for GPU memory hierarchy analysis and optimization. Analyze memory access patterns, detect bank conflicts, optimize cache utilization, profile global memory bandwidth, and generate optimized memory access code patterns.

a5c-aigithub.com/a5c-aiGitHub ↗
claude-codecodexcan modify filesMIT
Install
npx skills add a5c-ai/babysitter --skill gpu-memory-analysis --agent claude-code

Same command for any agent — swap --agent for codex, cursor, copilot.

Facts
Files in the skill folder: 2
SKILL.md size: 10 KB
Bundled scripts: none
Version: 1.0.0
Declared author: babysitter-sdk
Allowed tools: Bash(*)ReadWriteEditGlobGrepWebFetch
Path: library/specializations/gpu-programming/skills/gpu-memory-analysis/SKILL.md
Open the folder on GitHub →
Where it comes from
Stars: 1,642
Language: JavaScript

Weekly change comes from our own snapshots, not the repository page — it measures attention, not adoption.

From the SKILL.md

# gpu-memory-analysis You are **gpu-memory-analysis** - a specialized skill for GPU memory hierarchy analysis and optimization. This skill provides expert capabilities for understanding and optimizing GPU memory access patterns. ## Overview This skill enables AI-powered GPU memory optimization including: - Analyze memory access patterns (coalescing, striding) - Detect and resolve shared memory bank conflicts - Optimize L1/L2 cache utilization - Configure shared memory vs L1 cache partitioning - Analyze texture and constant memory usage - Profile global memory bandwidth utilization - Identify unnecessary memory transactions - Generate optimized memory access code patterns ## Prerequisites - CUDA Toolkit 11.0+ - Nsight Compute (for memory profiling) - compute-sanitizer (for memory validation) ## Capabilities ### 1. Memory Access Pattern Analysis Analyze coalescing and striding: ```cuda // Good: Coalesced access (threads access consecutive addresses) __global__ void coalescedAccess(float* data, int n) { int idx = blockIdx.x * blockDim.x + threadIdx.x; if (idx < n) { float val = data[idx]; // Coalesced: thread i accesses data[i] data[idx] = val * 2.0f; } } // Bad: Strided access (cache

What's inside
Steps it walks through
  1. Overview
  2. Prerequisites
  3. Capabilities
  4. 1. Memory Access Pattern Analysis
  5. 2. Bank Conflict Detection
  6. 3. Cache Optimization
  7. 4. Shared Memory Optimization
  8. 5. Global Memory Bandwidth Profiling
  9. 6. Texture and Constant Memory
  10. 7. Memory Transaction Analysis
  11. 8. Memory Access Pattern Generation
  12. Process Integration
  13. Output Format
  14. Dependencies
Ships with 1 file
  • README.md
Commands it runs
Profile memory throughput
ncu --metrics \
dram__bytes_write.sum.per_second \
Check memory efficiency
smsp__sass_average_data_bytes_per_sector_mem_global_op_st.ratio \
More from babysitter
All skills →
About this skill
What does the gpu-memory-analysis skill do?

Specialized skill for GPU memory hierarchy analysis and optimization. Analyze memory access patterns, detect bank conflicts, optimize cache utilization, profile global memory bandwidth, and generate optimized memory access code patterns.

How do I install it?

Run `npx skills add a5c-ai/babysitter --skill gpu-memory-analysis --agent claude-code` — it drops the skill into your project so the agent can pick it up. Swap the --agent value for codex, cursor or copilot if you use one of those.

Where does this skill come from?

From a5c-ai/babysitter, a repository with 1,642 stars. We read it straight from the repository tree rather than a submitted listing, so what you see here is what is actually published.

Is a popular skill a good skill?

Not necessarily. Stars measure attention, not adoption — a repository can trend for a week and be abandoned. That is why we show the weekly change from our own snapshots next to the total, instead of a single flattering number.

Keep going